@@ -1,3 +1,4 @@
+from requests.models import Response
 from .settings import settings
 import pandas as pd
 import numpy as np
@@ -265,6 +266,7 @@ class _DataFrame:
 
             offset = response.json()["data"]["items"]
             count = 0
+            threadlist = []
             for x in range(0 + offset, len(dataframe.index) + offset):
                 threadlist.append(Thread(target=Worker, args=(self, amountSent, offset, dataframe, count)))
                 if i % n_jobs == 0:
@@ -570,3 +572,27 @@ class _DataFrame:
             currentLoop += 1
 
         return pd.DataFrame(data)
+
+    def DeleteItems(self, ItemIDArray=[]):
+        if not Auth.tokenValid():
+            Auth.refreshToken()
+        
+        if len(ItemIDArray) > 0:
+
+            x = {
+                "data": ItemIDArray
+            }        
+                    
+            itemIDString = json.dump(x)
+
+            response = requests.delete(settings.baseURL + "api/item/defualt/asd/dataframe",
+                        json={
+                            "content": itemIDString
+                        },
+                        headers={
+                            'Authorization': 'Bearer ' + settings.token
+                        })
+        else:
+            raise Exception('No IDs to delete')
+
+        return response
